function [M_la,N_la,G_la,B_la,N_F_la,nu_0_dot_la ] = LinearModelMatricesLateral(beta_0, U_0, W_0, P_0, Q_0, R_0,delta_T_0, delta_A_0, delta_R_0, phi_0, theta_0, m,g,b,S,rho,aero,kinetics)
%LINEARMODELMATRICES Is a function which returns a linear model in the 
%longitudinal channel based on the trajectory of the input
% direction
    V_T = U_0;
    q_bar = 0.5*rho*V_T^2;

    M_la = [    V_T*m   0               0;
            0       kinetics.I_x    0;
            0       0               kinetics.I_z];

    N_la = [    0   -m*W_0                              m*U_0;
            0   0                                   (kinetics.I_z-kinetics.I_y)*Q_0;
            0   (kinetics.I_y - kinetics.I_x)*Q_0   0];

    G_la = [    -m*g*cos(theta_0)*cos(phi_0)   0  0]';

        Y_beta =    q_bar*S*aero.sideforce.C_Y_beta;
        Y_p =       S*b/4*rho*V_T*aero.sideforce.C_Y_p;
        Y_r =       S*b/4*rho*V_T*aero.sideforce.C_Y_r;
        L_beta =    b*q_bar*S*aero.roll.C_l_beta;
        L_p =       S*b^2/4*rho*V_T*aero.roll.C_l_p;
        L_r =       S*b^2/4*rho*V_T*aero.roll.C_l_r;
        N_beta =    b*q_bar*S*aero.yaw.C_n_beta;
        N_p =       S*b^2/4*rho*V_T*aero.yaw.C_n_p;
        N_r =       S*b^2/4*rho*V_T*aero.yaw.C_n_r;
        Y_delta_a = 0;
        Y_delta_r = q_bar*S*aero.sideforce.C_Y_delta_r;
        L_delta_a = b*q_bar*S*aero.roll.C_l_delta_a;
        L_delta_r = b*q_bar*S*aero.roll.C_l_delta_r;
        N_delta_a = b*q_bar*S*aero.yaw.C_n_delta_a;
        N_delta_r = b*q_bar*S*aero.yaw.C_n_delta_r;

    B_la = [    Y_delta_a   Y_delta_r;
            L_delta_a   L_delta_r;
            N_delta_a   N_delta_r];    
    N_F_la = [  Y_beta     Y_p     Y_r;
            L_beta     L_p     L_r;
            N_beta     N_p     N_r];
    %Equlibrium point
        Y_0 = q_bar*S*  (aero.sideforce.C_Y_0 + aero.sideforce.C_Y_beta*beta_0 + aero.sideforce.C_Y_delta_r*delta_R_0) ....
        + aero.sideforce.C_Y_T_C*delta_T_0 + S*b/4*rho*V_T*aero.sideforce.C_Y_p*P_0 + S*b/4*rho*V_T*aero.sideforce.C_Y_r*R_0;
        L_0 = b*q_bar*S*(aero.roll.C_l_0 + aero.roll.C_l_beta*beta_0 + aero.roll.C_l_delta_a*delta_A_0 + aero.roll.C_l_delta_r*delta_R_0) ....
        + b*aero.roll.C_l_T_C*delta_T_0 + S*b^2/4*rho*V_T*aero.roll.C_l_p*P_0 + S*b^2/4*rho*V_T*aero.roll.C_l_r*R_0;  
        N_0 = b*q_bar*S*(aero.yaw.C_n_0 + aero.yaw.C_n_beta*beta_0 + aero.yaw.C_n_delta_a*delta_A_0 + aero.yaw.C_n_delta_r*delta_R_0) ....
        + b*aero.yaw.C_n_T_C*delta_T_0 + S*b^2/4*rho*V_T*aero.yaw.C_n_p*P_0 + S*b^2/4*rho*V_T*aero.yaw.C_n_r*R_0;

        beta_0_dot = 1/V_T*(-U_0*R_0 + W_0*P_0 + g*cos(theta_0)*sin(phi_0) + 1/m*Y_0); %decoupling:   
        P_0_dot = 1/kinetics.I_x*(-(kinetics.I_z - kinetics.I_y)*Q_0*R_0 + L_0); %decoupling: 
        R_0_dot = 1/kinetics.I_z*(-(kinetics.I_y - kinetics.I_x)*P_0*Q_0 + N_0); %decoupling: 
    nu_0_dot_la = [beta_0_dot; P_0_dot; R_0_dot];

end

