function [ M_lo, N_lo, G_lo, B_lo, N_F_lo, nu_0_dot_lo ] = LinearModelMatricesLongitudinal(alpha_0, U_0, V_0, W_0, P_0, Q_0, R_0, phi_0, theta_0,delta_T_0, delta_E_0, delta_F_0, m,g,c_bar,S,rho,aero,thrust,kinetics)
%LINEARMODELMATRICES Is a function which returns a linear model in the 
%longitudinal channel based on the trajectory of the input
%Constants
V_T = U_0;
q_bar = 0.5*rho*V_T^2;   

M_lo = [    m   0       0;
            0   V_T*m   0;
            0   0       kinetics.I_y];

N_lo = [    0       V_T*m*Q_0   m*W_0;
            -m*Q_0  0           -m*U_0;
            0       0           0];

G_lo = [m*g*cos(theta_0);
        m*g*sin(theta_0)*cos(phi_0);
        0];

    X_u = S*rho*U_0* (-aero.drag.C_D_0 - aero.drag.C_D_alpha*alpha_0 - aero.drag.C_D_alpha_2*alpha_0^2 - aero.drag.C_D_delta_f*delta_F_0 - aero.drag.C_D_delta_f_2*delta_F_0^2 + ....
        alpha_0*(aero.lift.C_L_0 + aero.lift.C_L_alpha*alpha_0 + aero.lift.C_L_delta_e*delta_E_0 + aero.lift.C_L_delta_f*delta_F_0 + aero.lift.C_L_delta_f_2*delta_F_0^2));
    X_alpha = q_bar*S*  (-aero.drag.C_D_alpha - 2*aero.drag.C_D_alpha_2*alpha_0 + aero.lift.C_L_0 + 2*aero.lift.C_L_alpha*alpha_0 + aero.lift.C_L_delta_e*delta_E_0 + aero.lift.C_L_delta_f*delta_F_0 + aero.lift.C_L_delta_f_2*delta_F_0^2);
    X_q = 0;
    Z_u = S*rho*U_0* (-alpha_0*(aero.drag.C_D_0 + aero.drag.C_D_alpha*alpha_0 + aero.drag.C_D_alpha_2*alpha_0^2 + aero.drag.C_D_delta_f*delta_F_0 + aero.drag.C_D_delta_f_2*delta_F_0^2) ....
        - (aero.lift.C_L_0 + aero.lift.C_L_alpha*alpha_0 + aero.lift.C_L_delta_e*delta_E_0 + aero.lift.C_L_delta_f*delta_F_0 + aero.lift.C_L_delta_f_2*delta_F_0^2));
    Z_alpha = q_bar*S*  (-aero.drag.C_D_0 - 2*aero.drag.C_D_alpha*alpha_0 - 3*aero.drag.C_D_alpha_2*alpha_0^2 - aero.drag.C_D_delta_f*delta_F_0 - aero.drag.C_D_delta_f_2*delta_F_0^2 - aero.lift.C_L_alpha) ....
        - aero.drag.C_D_T_C*delta_T_0;
    Z_q = 0;
    M_u = S*rho*U_0*c_bar*(aero.pitch.C_m_alpha*alpha_0 + aero.pitch.C_m_delta_e*delta_E_0) + S*rho*c_bar^2*Q_0/4;
    M_alpha = q_bar*S*c_bar*aero.pitch.C_m_alpha;
    M_q = q_bar*S*c_bar*aero.pitch.C_m_q*c_bar/(2*V_T);

    X_delta_T = -aero.drag.C_D_T_C + 1;
    X_delta_E = q_bar*S*(aero.lift.C_L_delta_e*alpha_0);
    X_delta_F = q_bar*S*(-aero.drag.C_D_delta_f - 2*aero.drag.C_D_delta_f_2*delta_F_0 + alpha_0*aero.lift.C_L_delta_f + 2*aero.lift.C_L_delta_f_2*alpha_0*delta_F_0);
    Z_delta_T = -aero.drag.C_D_T_C*alpha_0;
    Z_delta_E = q_bar*S*(-aero.lift.C_L_delta_e);
    Z_delta_F = q_bar*S*(-alpha_0*aero.drag.C_D_delta_f - 2*alpha_0*aero.drag.C_D_delta_f_2*delta_F_0 - aero.lift.C_L_delta_f - 2*aero.lift.C_L_delta_f_2*delta_F_0);
    M_delta_T = thrust.r_t_b(3);
    M_delta_E = q_bar*S*c_bar*(aero.pitch.C_m_delta_e);
    M_delta_F = 0;

B_lo = [X_delta_T   X_delta_E   X_delta_F;
        Z_delta_T   Z_delta_E   Z_delta_F;
        M_delta_T   M_delta_E   M_delta_F];
N_F_lo = [  X_u     X_alpha     X_q;
            Z_u     Z_alpha     Z_q;
            M_u     M_alpha     M_q];
    X_0 = q_bar*S*(   -(aero.drag.C_D_0 + aero.drag.C_D_alpha*alpha_0 + aero.drag.C_D_alpha_2*alpha_0^2 + aero.drag.C_D_T_C*delta_T_0/(q_bar*S) + aero.drag.C_D_delta_f*delta_F_0 + aero.drag.C_D_delta_f_2*delta_F_0^2) + ....
                     alpha_0*(aero.lift.C_L_0 + aero.lift.C_L_alpha*alpha_0 + aero.lift.C_L_delta_e*delta_E_0 + aero.lift.C_L_delta_f*delta_F_0 + aero.lift.C_L_delta_f_2*delta_F_0^2)) + delta_T_0;
    Z_0 = q_bar*S*(-alpha_0*(aero.drag.C_D_0 + aero.drag.C_D_alpha*alpha_0 + aero.drag.C_D_alpha_2*alpha_0^2 + aero.drag.C_D_T_C*delta_T_0/(q_bar*S) + aero.drag.C_D_delta_f*delta_F_0 + aero.drag.C_D_delta_f_2*delta_F_0^2) ....
        - (aero.lift.C_L_0 + aero.lift.C_L_alpha*alpha_0 + aero.lift.C_L_delta_e*delta_E_0 + aero.lift.C_L_delta_f*delta_F_0 + aero.lift.C_L_delta_f_2*delta_F_0^2));
    M_0 = q_bar*S*c_bar* (aero.pitch.C_m_alpha*alpha_0 + aero.pitch.C_m_delta_e*delta_E_0 + aero.pitch.C_m_q*c_bar*Q_0/(2*V_T)) + thrust.r_t_b(3)*delta_T_0; %

    U_0_dot =  -Q_0*W_0 + R_0*V_0 - g*sin(theta_0) + 1/m*X_0; %decoupling: 
    alpha_0_dot = 1/V_T*(-V_0*P_0 + Q_0*U_0 +g*cos(theta_0)*cos(phi_0)  + 1/m*Z_0);%decoupling: 
    Q_0_dot =  1/(kinetics.I_y)*(-(kinetics.I_x - kinetics.I_z)*P_0*R_0 + M_0); % decoupling: 
nu_0_dot_lo = [U_0_dot; alpha_0_dot; Q_0_dot];


end

