% This matlab script is a elaboration of a scriped developed by Kre Vistnes 
% Initialization of simulation plant as well as control plant and observer


%% Common constants
other.g       = 9.80665;	% The acceleration of gravity
other.rho_air = 1.1907;     % Density of air


%% Initialization constants
init.p     = [0 0 -0.676]'; % Initial position of BODY in NED
init.v     = [51.4  0 0]';      % Initial velocities of BODY in NED (100 kn = 51,4 m/s)
init.euler = init_euler_angles;      % Initial orientation of BODY in NED phi = 0 deg, theta = 0 deg, psi = 0 deg
init.omega = [0     0 0]';          % Initial angular velocities of BODY in NED

init.q     = euler2q(init.euler(1),init.euler(2),init.euler(3));

init.x = [init.p; init.euler; init.v; init.omega];
init.alpha = -0.696*pi/180;
init.beta = 1.17*pi/180;
modelstatesat = [inf inf inf 2*pi 2*pi 4*pi 100 100 100 10*pi/180 10*pi/180 10*pi/180]';

%% Rigid-Body Kinetics
% Aircraft Mass
kinetics.m   = 745;

% Radius of gyration
kinetics.r_x = 1.42;	% Radius of gyration in roll [m]
kinetics.r_y = 1.96;	% Radius of gyration in pitch [m]
kinetics.r_z = 2.33;    % Radius of gyration in yaw [m]

% Moments of inertia
kinetics.I_x = kinetics.m*kinetics.r_x^2;
kinetics.I_y = kinetics.m*kinetics.r_y^2;
kinetics.I_z = kinetics.m*kinetics.r_z^2;
kinetics.I_xz = 0;

% Inertia Matrix
kinetics.I_b = [kinetics.I_x 0 -kinetics.I_xz  ; ...
                    0   kinetics.I_y   0       ; ...
               -kinetics.I_xz 0  kinetics.I_z] ;

% Rigid-Body System Inertia Matrix
kinetics.M_RB = [kinetics.m*eye(3) zeros(3) ; 
                 zeros(3) kinetics.I_b];
kinetics.M_RBinv = kinetics.M_RB^(-1);

%% Landing gear
landingGear.K_s     = diag([0 0 1*10^5]);  % Spring coefficient of back wheels
landingGear.K_s_ns  = diag([0 0 1*10^5]);  % Spring coefficient of nose wheel
landingGear.K_d     = diag([0 0 3*10^4]);   % Damping coefficient when wheel 
                                        % is compressed 
landingGear.K_d_bar = diag([0 0 0]);    % Damping coefficient when wheel 
                                        % is not compressed

landingGear.r_nw    = [ 1.1  ; ...    % Position of nose wheel with respect
                        0.0  ; ...    % to {b}, expressed in {b}, [m]
                        0.7] ;        
landingGear.r_lw    = [-0.6  ; ...    % Position of left weel with respect  
                       -0.5  ; ...    % to {b}, expressed in {b}, [m]
                        0.7] ;        
landingGear.r_rw    = [-0.6  ; ...    % Position of right wheel with respect
                        0.5  ; ...    % to {b}, expressed in {b}, [m]
                        0.7] ;        


%% Location of thrust force
thrust.r_t_b = [2.225 0 0.122]';	% Location of thrust force with respect 
                                    % to {b}, expressed in {b}, [m]

                                    

%% Control Surface Saturation

% Ailerons
controlSurface.delta_a.maxPosDef = 15*pi/180;    % Max Positive Deflection [rad]
controlSurface.delta_a.maxNegDef = -20*pi/180;   % Max Negative Deflection [rad]

% Elevators
controlSurface.delta_e.maxPosDef = 24*pi/180;    % Max Positive Deflection [rad]
controlSurface.delta_e.maxNegDef = -28*pi/180;   % Max Negative Deflection [rad]

% Flaps
controlSurface.delta_f.maxPosDef = 40*pi/180;	 % Max Positive Deflection [rad]
controlSurface.delta_f.maxNegDef = 0*pi/180;     % Max Negative Deflection [rad]

% Rudder
controlSurface.delta_r.maxPosDef = 17;           % Max Positive Deflection [rad]
controlSurface.delta_r.maxNegDef = -17;          % Max Negative Deflection [rad]

% Thrust
controlSurface.thrust.maxPosThrust = 3000;       % Max Positive Thrust [N]
controlSurface.thrust.maxNegThrust = 0;          % Max Negative Thrust [N]


%% Aerodynamics

% Wing Shape Parameters
aero.wingShape.b = 5.9;     % Wing span (i.e. tip to tip) [m]
aero.wingShape.c_bar = 1.6;	% Mean aerodynamic chord [m]
aero.wingShape.S = 7.5;     % Wing area [m^2]

% Drag coefficient
aero.drag.C_D_0 = 0.06;
aero.drag.C_D_alpha = 0.58;
aero.drag.C_D_alpha_2 = 1.99;
aero.drag.C_D_T_C = 0.09;
aero.drag.C_D_delta_f = 0.35;
aero.drag.C_D_delta_f_2 = -0.13;

% Lift coefficient
aero.lift.C_L_0 = 0.78;
aero.lift.C_L_alpha = 12.43;
aero.lift.C_L_delta_e = 1.59;
aero.lift.C_L_delta_f = 3.44;
aero.lift.C_L_delta_f_2 = -2.34;

% Sideforce coefficient
aero.sideforce.C_Y_0 = 0.001;
aero.sideforce.C_Y_beta = -2.13;
aero.sideforce.C_Y_T_C = 0.07;
aero.sideforce.C_Y_delta_r = 0.40;
aero.sideforce.C_Y_p = -0.51;
aero.sideforce.C_Y_r = 1.50;

% Rolling moment coefficient
aero.roll.C_l_0 = 0.00;
aero.roll.C_l_beta = -0.31;
aero.roll.C_l_T_C = -0.04;
aero.roll.C_l_delta_a = -1.97;
aero.roll.C_l_delta_r = 0.06;
aero.roll.C_l_p = -6.57;
aero.roll.C_l_r = 1.59;

% Pitching moment coefficient
aero.pitch.C_m_0 = 0.00;
aero.pitch.C_m_alpha = -5.51;
aero.pitch.C_m_delta_e = -5.50;
aero.pitch.C_m_q = -43.85;

% Yawing moment coefficient
aero.yaw.C_n_0 = -0.02;
aero.yaw.C_n_beta = 0.91;
aero.yaw.C_n_T_C = 0.01;
aero.yaw.C_n_delta_a = -0.17;
aero.yaw.C_n_delta_r = -0.37;
aero.yaw.C_n_p = -1.57;
aero.yaw.C_n_r = -2.05;